@@ -1,4 +1,7 @@
 from .intraday_candles import IntradayCandles
 from .historical_candles import HistoricalCandles
 from .authenticator import Authenticator
-from .bulk_data import BulkData
\ No newline at end of file
+from .bulk_data import BulkData
+from .hfn import HighFrequencyNews
+from .quotes import Quotes
+from .intraday_tick_data import IntradayTickData
\ No newline at end of file
